BoardProvider class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
boardScroll()
→ void
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
initializeBoard({required List<BoardListsData> data, Color backgroundColor = Colors.white, TextStyle? textStyle, dynamic onItemTap(int? itemIndex, int? listIndex)?, dynamic onItemLongPress(int? itemIndex, int? listIndex)?, dynamic onListTap(int? listIndex)?, dynamic onListLongPress(int? listIndex)?, double? displacementX, double? displacementY, void onItemReorder(int? oldCardIndex, int? newCardIndex, int? oldListIndex, int? newListIndex)?, void onListReorder(int? oldListIndex, int? newListIndex)?, void onListRename(String? oldName, String? newName)?, void onNewCardInsert(String? cardIndex, String? listIndex, String? text)?, Decoration? boardDecoration, Decoration? listDecoration, Widget listTransitionBuilder(Widget child, Animation<double> animation)?, Widget cardTransitionBuilder(Widget child, Animation<double> animation)?, required Duration cardTransitionDuration, required Duration listTransitionDuration, Color? cardPlaceHolderColor, Color? listPlaceHolderColor, ScrollConfig? boardScrollConfig, ScrollConfig? listScrollConfig})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setcanDrag({required bool value, required int itemIndex, required int listIndex})
→ void
-
-
setsState()
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateValue({required double dx, required double dy})
→ void
-