BoardState class

Constructors

BoardState({required List<BoardList> lists, required ScrollController controller, int? dragListIndex, dynamic onItemTap(int? itemIndex, int? listIndex)?, dynamic onItemLongPress(int? itemIndex, int? listIndex)?, ScrollConfig? boardScrollConfig, ScrollConfig? listScrollConfig, VoidCallback? setstate, dynamic onListTap(int? listIndex)?, void onItemReorder(int? oldCardIndex, int? newCardIndex, int? oldListIndex, int? newListIndex)?, void onListReorder(int? oldListIndex, int? newListIndex)?, void onListRename(String? oldName, String? newName)?, void onNewCardInsert(String? cardIndex, String? listIndex, String? text)?, double? displacementX, double? displacementY, int? newCardIndex, int? newCardListIndex, dynamic onListLongPress(int? listIndex)?, int? dragItemIndex, TextStyle? textStyle, Color? backgroundColor = Colors.white, Color? cardPlaceholderColor, Color? listPlaceholderColor, Widget cardTransitionBuilder(Widget child, Animation<double> animation)?, Widget listTransitionBuilder(Widget child, Animation<double> animation)?, Decoration? listDecoration, Decoration? boardDecoration, int? dragItemOfListIndex, bool isElementDragged = false, Duration cardTransitionDuration = const Duration(milliseconds: 150), Duration listTransitionDuration = const Duration(milliseconds: 150), bool isListDragged = false})

Properties

backgroundColor ↔ Color?
getter/setter pair
boardDecoration ↔ Decoration?
getter/setter pair
boardScrollConfig → ScrollConfig?
final
cardPlaceholderColor ↔ Color?
getter/setter pair
cardTransitionBuilder → Widget Function(Widget child, Animation<double> animation)?
final
cardTransitionDuration → Duration
final
controller ↔ ScrollController
getter/setter pair
displacementX ↔ double?
getter/setter pair
displacementY ↔ double?
getter/setter pair
dragItemIndex ↔ int?
getter/setter pair
dragItemOfListIndex ↔ int?
getter/setter pair
dragListIndex ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isElementDragged ↔ bool
getter/setter pair
isListDragged ↔ bool
getter/setter pair
listDecoration ↔ Decoration?
getter/setter pair
listPlaceholderColor ↔ Color?
getter/setter pair
lists ↔ List<BoardList>
getter/setter pair
listScrollConfig → ScrollConfig?
final
listTransitionBuilder → Widget Function(Widget child, Animation<double> animation)?
final
listTransitionDuration → Duration
final
newCardFocused ↔ bool?
getter/setter pair
newCardIndex ↔ int?
getter/setter pair
newCardListIndex ↔ int?
getter/setter pair
newCardTextController ↔ TextEditingController
getter/setter pair
onItemLongPress ↔ dynamic Function(int? itemIndex, int? listIndex)?
getter/setter pair
onItemReorder → void Function(int? oldCardIndex, int? newCardIndex, int? oldListIndex, int? newListIndex)?
final
onItemTap ↔ dynamic Function(int? itemIndex, int? listIndex)?
getter/setter pair
onListLongPress ↔ dynamic Function(int? listIndex)?
getter/setter pair
onListRename → void Function(String? oldName, String? newName)?
final
onListReorder → void Function(int? oldListIndex, int? newListIndex)?
final
onListTap ↔ dynamic Function(int? listIndex)?
getter/setter pair
onNewCardInsert → void Function(String? cardIndex, String? listIndex, String? text)?
final
previousDragListIndex ↔ int?
getter/setter pair
prevItemOfListIndex ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setstate ↔ VoidCallback?
getter/setter pair
textStyle ↔ TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited