BoardList class

Constructors

BoardList({required List<ListItem> items, BuildContext? context, double? height, double? width, Widget? header, Widget? footer, VoidCallback? setState, Color? headerBackgroundColor = const Color.fromARGB(255, 247, 248, 252), Color? footerBackgroundColor = const Color.fromARGB(255, 247, 248, 252), double? x, Widget? child, Color? backgroundColor = const Color.fromARGB(255, 247, 248, 252), double? y, required ScrollController scrollController, required String title})

Properties

backgroundColor ↔ Color?
getter/setter pair
child ↔ Widget?
getter/setter pair
context ↔ BuildContext?
getter/setter pair
getter/setter pair
footerBackgroundColor ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
headerBackgroundColor ↔ Color?
getter/setter pair
height ↔ double?
getter/setter pair
items ↔ List<ListItem>
getter/setter pair
nameController ↔ TextEditingController
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController ↔ ScrollController
getter/setter pair
setState ↔ VoidCallback?
getter/setter pair
title ↔ String
getter/setter pair
width ↔ double?
getter/setter pair
x ↔ double?
getter/setter pair
y ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited