BoardListsData class

Constructors

BoardListsData({String? title, Widget? header, Widget? footer, required List<Widget> items, Color? footerBackgroundColor = const Color.fromRGBO(247, 248, 252, 1), Color? headerBackgroundColor = const Color.fromARGB(255, 247, 248, 252), Color? backgroundColor = const Color.fromARGB(255, 247, 248, 252), double width = 300})

Properties

backgroundColor ↔ Color?
getter/setter pair
getter/setter pair
footerBackgroundColor ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
headerBackgroundColor ↔ Color?
getter/setter pair
items → List<Widget>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited