DraggedItemState class

Constructors

DraggedItemState({BuildContext? context, required Widget child, VoidCallback? setState, required int? listIndex, required int? itemIndex, required double height, required double width, required double x, required double y})

Properties

child ↔ Widget
getter/setter pair
context ↔ BuildContext?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
itemIndex ↔ int?
getter/setter pair
listIndex ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setState ↔ VoidCallback?
getter/setter pair
width ↔ double
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited