ListItem class

Constructors

ListItem({BuildContext? context, required Widget child, required Widget prevChild, required int listIndex, required int index, Size? actualSize, double? height, bool? containsPlaceholder, VoidCallback? setState, bool? addedBySystem, bool? bottomPlaceholder = false, Color? backgroundColor, double? width, double? x, double? y, bool? isNew = false})

Properties

actualSize ↔ Size?
getter/setter pair
addedBySystem ↔ bool?
getter/setter pair
backgroundColor ↔ Color?
getter/setter pair
bottomPlaceholder ↔ bool?
getter/setter pair
child ↔ Widget
getter/setter pair
containsPlaceholder ↔ bool?
getter/setter pair
context ↔ BuildContext?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
index ↔ int
getter/setter pair
isNew ↔ bool?
getter/setter pair
listIndex ↔ int
getter/setter pair
prevChild ↔ Widget
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setState ↔ VoidCallback?
getter/setter pair
width ↔ double?
getter/setter pair
x ↔ double?
getter/setter pair
y ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited